summaryrefslogtreecommitdiffstats
path: root/qtruby/rubylib/designer/rbuic/form.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'qtruby/rubylib/designer/rbuic/form.cpp')
-rw-r--r--qtruby/rubylib/designer/rbuic/form.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/qtruby/rubylib/designer/rbuic/form.cpp b/qtruby/rubylib/designer/rbuic/form.cpp
index 42ec751f..13241e82 100644
--- a/qtruby/rubylib/designer/rbuic/form.cpp
+++ b/qtruby/rubylib/designer/rbuic/form.cpp
@@ -62,13 +62,13 @@ static TQByteArray unzipXPM( TQString data, ulong& length )
r += l - 'a' + 10;
ba[ i ] = r;
}
// qUncompress() expects the first 4 bytes to be the expected length of the
// uncompressed data
ba[0] = ( length & 0xff000000 ) >> 24;
ba[1] = ( length & 0x00ff0000 ) >> 16;
ba[2] = ( length & 0x0000ff00 ) >> 8;
ba[3] = ( length & 0x000000ff );
- TQByteArray baunzip = qUncompress( ba, baSize );
+ TQByteArray baunzip = tqUncompress( ba, baSize );
delete[] ba;
return baunzip;
}
@@ -62,13 +62,13 @@ static TQByteArray unzipXPM( TQString data, ulong& length )
ba[ i ] = r;
}
- // qUncompress() expects the first 4 bytes to be the expected length of the
+ // tqUncompress() expects the first 4 bytes to be the expected length of the
// uncompressed data
ba[0] = ( length & 0xff000000 ) >> 24;